package cn.com.infosec.jce.provider;

import cn.com.infosec.crypto.BlockCipher;
import cn.com.infosec.crypto.BufferedBlockCipher;
import cn.com.infosec.crypto.CipherParameters;
import cn.com.infosec.crypto.DataLengthException;
import cn.com.infosec.crypto.InvalidCipherTextException;
import cn.com.infosec.crypto.engines.AESFastEngine;
import cn.com.infosec.crypto.engines.BlowfishEngine;
import cn.com.infosec.crypto.engines.CAST5Engine;
import cn.com.infosec.crypto.engines.CAST6Engine;
import cn.com.infosec.crypto.engines.DESEngine;
import cn.com.infosec.crypto.engines.DESedeEngine;
import cn.com.infosec.crypto.engines.GOST28147Engine;
import cn.com.infosec.crypto.engines.IDEAEngine;
import cn.com.infosec.crypto.engines.RC2Engine;
import cn.com.infosec.crypto.engines.RC532Engine;
import cn.com.infosec.crypto.engines.RC564Engine;
import cn.com.infosec.crypto.engines.RC6Engine;
import cn.com.infosec.crypto.engines.RijndaelEngine;
import cn.com.infosec.crypto.engines.SEEDEngine;
import cn.com.infosec.crypto.engines.SerpentEngine;
import cn.com.infosec.crypto.engines.SkipjackEngine;
import cn.com.infosec.crypto.engines.TEAEngine;
import cn.com.infosec.crypto.engines.TwofishEngine;
import cn.com.infosec.crypto.engines.XTEAEngine;
import cn.com.infosec.crypto.modes.AEADBlockCipher;
import cn.com.infosec.crypto.modes.CBCBlockCipher;
import cn.com.infosec.crypto.modes.CCMBlockCipher;
import cn.com.infosec.crypto.modes.CFBBlockCipher;
import cn.com.infosec.crypto.modes.CTSBlockCipher;
import cn.com.infosec.crypto.modes.EAXBlockCipher;
import cn.com.infosec.crypto.modes.GOFBBlockCipher;
import cn.com.infosec.crypto.modes.OFBBlockCipher;
import cn.com.infosec.crypto.modes.OpenPGPCFBBlockCipher;
import cn.com.infosec.crypto.modes.PGPCFBBlockCipher;
import cn.com.infosec.crypto.modes.SICBlockCipher;
import cn.com.infosec.crypto.paddings.BlockCipherPadding;
import cn.com.infosec.crypto.paddings.ISO10126d2Padding;
import cn.com.infosec.crypto.paddings.ISO7816d4Padding;
import cn.com.infosec.crypto.paddings.PaddedBufferedBlockCipher;
import cn.com.infosec.crypto.paddings.TBCPadding;
import cn.com.infosec.crypto.paddings.X923Padding;
import cn.com.infosec.crypto.paddings.ZeroBytePadding;
import cn.com.infosec.crypto.params.KeyParameter;
import cn.com.infosec.crypto.params.ParametersWithIV;
import cn.com.infosec.crypto.params.ParametersWithRandom;
import cn.com.infosec.crypto.params.ParametersWithSBox;
import cn.com.infosec.crypto.params.RC2Parameters;
import cn.com.infosec.crypto.params.RC5Parameters;
import cn.com.infosec.jce.spec.GOST28147ParameterSpec;
import cn.com.infosec.util.Strings;
import java.security.AlgorithmParameters;
import java.security.InvalidAlgorithmParameterException;
import java.security.InvalidKeyException;
import java.security.InvalidParameterException;
import java.security.Key;
import java.security.NoSuchAlgorithmException;
import java.security.SecureRandom;
import java.security.spec.AlgorithmParameterSpec;
import javax.crypto.BadPaddingException;
import javax.crypto.IllegalBlockSizeException;
import javax.crypto.NoSuchPaddingException;
import javax.crypto.SecretKey;
import javax.crypto.ShortBufferException;
import javax.crypto.spec.IvParameterSpec;
import javax.crypto.spec.PBEParameterSpec;
import javax.crypto.spec.RC2ParameterSpec;
import javax.crypto.spec.RC5ParameterSpec;

public class JCEBlockCipher extends WrapCipherSpi implements PBE {
   // $FF: synthetic field
   static Class class$0;
   // $FF: synthetic field
   static Class class$1;
   // $FF: synthetic field
   static Class class$2;
   // $FF: synthetic field
   static Class class$3;
   // $FF: synthetic field
   static Class class$4;
   private Class[] availableSpecs;
   private BlockCipher baseEngine;
   private GenericBlockCipher cipher;
   private ParametersWithIV ivParam;
   private int ivLength;
   private boolean padded;
   private PBEParameterSpec pbeSpec;
   private String pbeAlgorithm;
   private String modeName;

   protected JCEBlockCipher(BlockCipher engine) {
      Class[] var2 = new Class[5];
      byte var3 = 0;
      Class var4;
      Class var10000;
      if ((var4 = class$0) == null) {
         try {
            var10000 = Class.forName("javax.crypto.spec.RC2ParameterSpec");
         } catch (ClassNotFoundException var9) {
            throw new NoClassDefFoundError(var9.getMessage());
         }

         var4 = var10000;
         class$0 = var10000;
      }

      var2[var3] = var4;
      var3 = 1;
      if ((var4 = class$1) == null) {
         try {
            var10000 = Class.forName("javax.crypto.spec.RC5ParameterSpec");
         } catch (ClassNotFoundException var8) {
            throw new NoClassDefFoundError(var8.getMessage());
         }

         var4 = var10000;
         class$1 = var10000;
      }

      var2[var3] = var4;
      var3 = 2;
      if ((var4 = class$2) == null) {
         try {
            var10000 = Class.forName("javax.crypto.spec.IvParameterSpec");
         } catch (ClassNotFoundException var7) {
            throw new NoClassDefFoundError(var7.getMessage());
         }

         var4 = var10000;
         class$2 = var10000;
      }

      var2[var3] = var4;
      var3 = 3;
      if ((var4 = class$3) == null) {
         try {
            var10000 = Class.forName("javax.crypto.spec.PBEParameterSpec");
         } catch (ClassNotFoundException var6) {
            throw new NoClassDefFoundError(var6.getMessage());
         }

         var4 = var10000;
         class$3 = var10000;
      }

      var2[var3] = var4;
      var3 = 4;
      if ((var4 = class$4) == null) {
         try {
            var10000 = Class.forName("cn.com.infosec.jce.spec.GOST28147ParameterSpec");
         } catch (ClassNotFoundException var5) {
            throw new NoClassDefFoundError(var5.getMessage());
         }

         var4 = var10000;
         class$4 = var10000;
      }

      JCEBlockCipher var11 = this;
      var2[var3] = var4;
      this.availableSpecs = var2;
      this.ivLength = 0;
      this.padded = true;
      this.pbeSpec = null;
      this.pbeAlgorithm = null;
      this.modeName = null;
      this.baseEngine = engine;
      BufferedGenericBlockCipher var10;
      var10 = new BufferedGenericBlockCipher.<init>(engine);
      var11.cipher = var10;
   }

   protected JCEBlockCipher(BlockCipher engine, int ivLength) {
      Class[] var3 = new Class[5];
      byte var4 = 0;
      Class var10000;
      Class var5;
      if ((var5 = class$0) == null) {
         try {
            var10000 = Class.forName("javax.crypto.spec.RC2ParameterSpec");
         } catch (ClassNotFoundException var10) {
            throw new NoClassDefFoundError(var10.getMessage());
         }

         var5 = var10000;
         class$0 = var10000;
      }

      var3[var4] = var5;
      var4 = 1;
      if ((var5 = class$1) == null) {
         try {
            var10000 = Class.forName("javax.crypto.spec.RC5ParameterSpec");
         } catch (ClassNotFoundException var9) {
            throw new NoClassDefFoundError(var9.getMessage());
         }

         var5 = var10000;
         class$1 = var10000;
      }

      var3[var4] = var5;
      var4 = 2;
      if ((var5 = class$2) == null) {
         try {
            var10000 = Class.forName("javax.crypto.spec.IvParameterSpec");
         } catch (ClassNotFoundException var8) {
            throw new NoClassDefFoundError(var8.getMessage());
         }

         var5 = var10000;
         class$2 = var10000;
      }

      var3[var4] = var5;
      var4 = 3;
      if ((var5 = class$3) == null) {
         try {
            var10000 = Class.forName("javax.crypto.spec.PBEParameterSpec");
         } catch (ClassNotFoundException var7) {
            throw new NoClassDefFoundError(var7.getMessage());
         }

         var5 = var10000;
         class$3 = var10000;
      }

      var3[var4] = var5;
      var4 = 4;
      if ((var5 = class$4) == null) {
         try {
            var10000 = Class.forName("cn.com.infosec.jce.spec.GOST28147ParameterSpec");
         } catch (ClassNotFoundException var6) {
            throw new NoClassDefFoundError(var6.getMessage());
         }

         var5 = var10000;
         class$4 = var10000;
      }

      var3[var4] = var5;
      this.availableSpecs = var3;
      this.ivLength = 0;
      this.padded = true;
      this.pbeSpec = null;
      this.pbeAlgorithm = null;
      this.modeName = null;
      this.baseEngine = engine;
      this.cipher = new BufferedGenericBlockCipher(engine);
      this.ivLength = ivLength / 8;
   }

   protected int engineGetBlockSize() {
      return this.baseEngine.getBlockSize();
   }

   protected byte[] engineGetIV() {
      ParametersWithIV var1;
      return (var1 = this.ivParam) != null ? var1.getIV() : null;
   }

   protected int engineGetKeySize(Key key) {
      return key.getEncoded().length * 8;
   }

   protected int engineGetOutputSize(int inputLen) {
      return this.cipher.getOutputSize(inputLen);
   }

   protected AlgorithmParameters engineGetParameters() {
      if (super.engineParams == null) {
         boolean var10001;
         AlgorithmParameters var7;
         AlgorithmParameters var8;
         if (this.pbeSpec != null) {
            try {
               var8 = AlgorithmParameters.getInstance(this.pbeAlgorithm, "INFOSEC");
            } catch (Exception var3) {
               var10001 = false;
               return null;
            }

            var7 = var8;

            try {
               super.engineParams = var7;
               var8.init(this.pbeSpec);
               return super.engineParams;
            } catch (Exception var2) {
               var10001 = false;
               return null;
            }
         } else if (this.ivParam != null) {
            String var1;
            if ((var1 = this.cipher.getUnderlyingCipher().getAlgorithmName()).indexOf(47) >= 0) {
               var1 = var1.substring(0, var1.indexOf(47));
            }

            Exception var10000;
            label55: {
               try {
                  var8 = AlgorithmParameters.getInstance(var1, "INFOSEC");
               } catch (Exception var5) {
                  var10000 = var5;
                  var10001 = false;
                  break label55;
               }

               var7 = var8;

               try {
                  super.engineParams = var7;
                  var8.init(this.ivParam.getIV());
                  return super.engineParams;
               } catch (Exception var4) {
                  var10000 = var4;
                  var10001 = false;
               }
            }

            Exception var6 = var10000;
            throw new RuntimeException(var6.toString());
         }
      }

      return super.engineParams;
   }

   protected void engineSetMode(String mode) {
      if ((this.modeName = Strings.toUpperCase(mode)).equals("ECB")) {
         this.ivLength = 0;
         this.cipher = new BufferedGenericBlockCipher(this.baseEngine);
      } else if (this.modeName.equals("CBC")) {
         this.ivLength = this.baseEngine.getBlockSize();
         this.cipher = new BufferedGenericBlockCipher(new CBCBlockCipher(this.baseEngine));
      } else {
         int mode1;
         BlockCipher var10005;
         if (this.modeName.startsWith("OFB")) {
            this.ivLength = this.baseEngine.getBlockSize();
            if (this.modeName.length() != 3) {
               mode1 = Integer.parseInt(this.modeName.substring(3));
               this.cipher = new BufferedGenericBlockCipher(new OFBBlockCipher(this.baseEngine, mode1));
            } else {
               var10005 = this.baseEngine;
               this.cipher = new BufferedGenericBlockCipher(new OFBBlockCipher(var10005, var10005.getBlockSize() * 8));
            }
         } else if (this.modeName.startsWith("CFB")) {
            this.ivLength = this.baseEngine.getBlockSize();
            if (this.modeName.length() != 3) {
               mode1 = Integer.parseInt(this.modeName.substring(3));
               this.cipher = new BufferedGenericBlockCipher(new CFBBlockCipher(this.baseEngine, mode1));
            } else {
               var10005 = this.baseEngine;
               this.cipher = new BufferedGenericBlockCipher(new CFBBlockCipher(var10005, var10005.getBlockSize() * 8));
            }
         } else if (this.modeName.startsWith("PGP")) {
            boolean mode2 = this.modeName.equalsIgnoreCase("PGPCFBwithIV");
            this.ivLength = this.baseEngine.getBlockSize();
            this.cipher = new BufferedGenericBlockCipher(new PGPCFBBlockCipher(this.baseEngine, mode2));
         } else if (this.modeName.equalsIgnoreCase("OpenPGPCFB")) {
            this.ivLength = 0;
            this.cipher = new BufferedGenericBlockCipher(new OpenPGPCFBBlockCipher(this.baseEngine));
         } else if (this.modeName.startsWith("SIC")) {
            if ((this.ivLength = this.baseEngine.getBlockSize()) < 16) {
               throw new IllegalArgumentException("Warning: SIC-Mode can become a twotime-pad if the blocksize of the cipher is too small. Use a cipher with a block size of at least 128 bits (e.g. AES)");
            }

            this.cipher = new BufferedGenericBlockCipher(new BufferedBlockCipher(new SICBlockCipher(this.baseEngine)));
         } else if (this.modeName.startsWith("CTR")) {
            this.ivLength = this.baseEngine.getBlockSize();
            this.cipher = new BufferedGenericBlockCipher(new BufferedBlockCipher(new SICBlockCipher(this.baseEngine)));
         } else if (this.modeName.startsWith("GOFB")) {
            this.ivLength = this.baseEngine.getBlockSize();
            this.cipher = new BufferedGenericBlockCipher(new BufferedBlockCipher(new GOFBBlockCipher(this.baseEngine)));
         } else if (this.modeName.startsWith("CTS")) {
            this.ivLength = this.baseEngine.getBlockSize();
            this.cipher = new BufferedGenericBlockCipher(new CTSBlockCipher(new CBCBlockCipher(this.baseEngine)));
         } else if (this.modeName.startsWith("CCM")) {
            this.ivLength = this.baseEngine.getBlockSize();
            this.cipher = new AEADGenericBlockCipher(new CCMBlockCipher(this.baseEngine));
         } else {
            if (!this.modeName.startsWith("EAX")) {
               throw new NoSuchAlgorithmException("can't support mode " + mode);
            }

            this.ivLength = this.baseEngine.getBlockSize();
            this.cipher = new AEADGenericBlockCipher(new EAXBlockCipher(this.baseEngine));
         }
      }

   }

   protected void engineSetPadding(String padding) {
      String var2;
      if ((var2 = Strings.toUpperCase(padding)).equals("NOPADDING")) {
         this.padded = false;
         if (this.cipher.wrapOnNoPadding()) {
            this.cipher = new BufferedGenericBlockCipher(new BufferedBlockCipher(this.cipher.getUnderlyingCipher()));
         }
      } else {
         if ("CCM".equals(this.modeName) || "EAX".equals(this.modeName)) {
            throw new NoSuchPaddingException("Only NoPadding can be used with AEAD modes.");
         }

         if (!var2.equals("PKCS5PADDING") && !var2.equals("PKCS7PADDING")) {
            if (var2.equals("ZEROBYTEPADDING")) {
               this.cipher = new BufferedGenericBlockCipher(this.cipher.getUnderlyingCipher(), new ZeroBytePadding());
            } else if (!var2.equals("ISO10126PADDING") && !var2.equals("ISO10126-2PADDING")) {
               if (!var2.equals("X9.23PADDING") && !var2.equals("X923PADDING")) {
                  if (!var2.equals("ISO7816-4PADDING") && !var2.equals("ISO9797-1PADDING")) {
                     if (var2.equals("TBCPADDING")) {
                        this.cipher = new BufferedGenericBlockCipher(this.cipher.getUnderlyingCipher(), new TBCPadding());
                     } else {
                        if (!var2.equals("WITHCTS")) {
                           throw new NoSuchPaddingException("Padding " + padding + " unknown.");
                        }

                        this.padded = false;
                        this.cipher = new BufferedGenericBlockCipher(new CTSBlockCipher(this.cipher.getUnderlyingCipher()));
                     }
                  } else {
                     this.cipher = new BufferedGenericBlockCipher(this.cipher.getUnderlyingCipher(), new ISO7816d4Padding());
                  }
               } else {
                  this.cipher = new BufferedGenericBlockCipher(this.cipher.getUnderlyingCipher(), new X923Padding());
               }
            } else {
               this.cipher = new BufferedGenericBlockCipher(this.cipher.getUnderlyingCipher(), new ISO10126d2Padding());
            }
         } else {
            this.cipher = new BufferedGenericBlockCipher(this.cipher.getUnderlyingCipher());
         }
      }

   }

   protected void engineInit(int opmode, Key key, AlgorithmParameterSpec params, SecureRandom random) {
      this.pbeSpec = null;
      this.pbeAlgorithm = null;
      super.engineParams = null;
      if (key instanceof SecretKey) {
         if (params == null && this.baseEngine.getAlgorithmName().startsWith("RC5-64")) {
            throw new InvalidAlgorithmParameterException("RC5 requires an RC5ParametersSpec to be passed in.");
         } else {
            Object var5;
            Object key1;
            byte[] key2;
            Object var10001;
            if (key instanceof JCEPBEKey) {
               JCEPBEKey key3;
               if ((key3 = (JCEPBEKey)key).getOID() != null) {
                  this.pbeAlgorithm = key3.getOID().getId();
               } else {
                  this.pbeAlgorithm = key3.getAlgorithm();
               }

               CipherParameters params7;
               if (key3.getParam() != null) {
                  params7 = key3.getParam();
                  PBEParameterSpec var27;
                  PBEParameterSpec var33 = var27 = new PBEParameterSpec;
                  JCEPBEKey var10002 = key3;
                  key2 = key3.getSalt();
                  var33.<init>(key2, var10002.getIterationCount());
                  this.pbeSpec = var27;
               } else {
                  if (!(params instanceof PBEParameterSpec)) {
                     throw new InvalidAlgorithmParameterException("PBE requires PBE parameters to be set.");
                  }

                  this.pbeSpec = (PBEParameterSpec)params;
                  params7 = PBE.Util.makePBEParameters(key3, params, this.cipher.getUnderlyingCipher().getAlgorithmName());
               }

               if (params7 instanceof ParametersWithIV) {
                  this.ivParam = (ParametersWithIV)params7;
               }

               key1 = params7;
            } else {
               KeyParameter params5;
               if (params == null) {
                  params5 = new KeyParameter.<init>(key.getEncoded());
                  key1 = params5;
               } else if (params instanceof IvParameterSpec) {
                  if (this.ivLength != 0) {
                     IvParameterSpec params4;
                     if ((params4 = (IvParameterSpec)params).getIV().length != this.ivLength && !this.modeName.equals("CCM") && !this.modeName.equals("EAX")) {
                        throw new InvalidAlgorithmParameterException("IV must be " + this.ivLength + " bytes long.");
                     }

                     ParametersWithIV var24;
                     ParametersWithIV var31 = var24 = new ParametersWithIV;
                     IvParameterSpec var10003 = params4;
                     params5 = new KeyParameter.<init>(key.getEncoded());
                     var31.<init>(params5, var10003.getIV());
                     this.ivParam = var31;
                     key1 = var24;
                  } else {
                     String params6;
                     if ((params6 = this.modeName) != null && params6.equals("ECB")) {
                        throw new InvalidAlgorithmParameterException("ECB mode does not use an IV");
                     }

                     KeyParameter var26;
                     var26 = new KeyParameter.<init>(key.getEncoded());
                     key1 = var26;
                  }
               } else {
                  label194: {
                     if (params instanceof GOST28147ParameterSpec) {
                        GOST28147ParameterSpec params1;
                        GOST28147ParameterSpec var10000 = params1 = (GOST28147ParameterSpec)params;
                        var10001 = var5 = new ParametersWithSBox;
                        KeyParameter var6;
                        var6 = new KeyParameter.<init>(key.getEncoded());
                        var10001.<init>(var6, params1.getSbox());
                        if (var10000.getIV() != null && this.ivLength != 0) {
                           key1 = new ParametersWithIV.<init>((CipherParameters)var5, params1.getIV());
                           this.ivParam = (ParametersWithIV)key1;
                           break label194;
                        }
                     } else if (params instanceof RC2ParameterSpec) {
                        RC2ParameterSpec params2;
                        RC2ParameterSpec var29 = params2 = (RC2ParameterSpec)params;
                        var10001 = var5 = new RC2Parameters;
                        key2 = key.getEncoded();
                        var10001.<init>(key2, params2.getEffectiveKeyBits());
                        if (var29.getIV() != null && this.ivLength != 0) {
                           key1 = new ParametersWithIV.<init>((CipherParameters)var5, params2.getIV());
                           this.ivParam = (ParametersWithIV)key1;
                           break label194;
                        }
                     } else {
                        if (!(params instanceof RC5ParameterSpec)) {
                           throw new InvalidAlgorithmParameterException("unknown parameter type.");
                        }

                        RC5ParameterSpec params3 = (RC5ParameterSpec)params;
                        var10001 = var5 = new RC5Parameters;
                        key2 = key.getEncoded();
                        var10001.<init>(key2, params3.getRounds());
                        if (!this.baseEngine.getAlgorithmName().startsWith("RC5")) {
                           throw new InvalidAlgorithmParameterException("RC5 parameters passed to a cipher that is not RC5.");
                        }

                        if (this.baseEngine.getAlgorithmName().equals("RC5-32")) {
                           if (params3.getWordSize() != 32) {
                              throw new InvalidAlgorithmParameterException("RC5 already set up for a word size of 32 not " + params3.getWordSize() + ".");
                           }
                        } else if (this.baseEngine.getAlgorithmName().equals("RC5-64") && params3.getWordSize() != 64) {
                           throw new InvalidAlgorithmParameterException("RC5 already set up for a word size of 64 not " + params3.getWordSize() + ".");
                        }

                        if (params3.getIV() != null && this.ivLength != 0) {
                           key1 = new ParametersWithIV.<init>((CipherParameters)var5, params3.getIV());
                           this.ivParam = (ParametersWithIV)key1;
                           break label194;
                        }
                     }

                     key1 = var5;
                  }
               }
            }

            label155: {
               if (this.ivLength != 0 && !(key1 instanceof ParametersWithIV)) {
                  SecureRandom params8;
                  if (random == null) {
                     params8 = new SecureRandom.<init>();
                  } else {
                     params8 = random;
                  }

                  if (opmode == 1 || opmode == 3) {
                     byte[] params9;
                     params8.nextBytes(params9 = new byte[this.ivLength]);
                     var10001 = var5 = new ParametersWithIV;
                     var10001.<init>((CipherParameters)key1, params9);
                     this.ivParam = (ParametersWithIV)var10001;
                     break label155;
                  }

                  if (this.cipher.getUnderlyingCipher().getAlgorithmName().indexOf("PGPCFB") < 0) {
                     throw new InvalidAlgorithmParameterException("no IV set when one expected");
                  }
               }

               var5 = key1;
            }

            if (random != null && this.padded) {
               key1 = new ParametersWithRandom.<init>((CipherParameters)var5, random);
            } else {
               key1 = var5;
            }

            Exception var30;
            label139: {
               boolean var35;
               switch (opmode) {
                  case 1:
                  case 3:
                     try {
                        this.cipher.init(true, (CipherParameters)key1);
                        break;
                     } catch (Exception var11) {
                        var30 = var11;
                        var35 = false;
                        break label139;
                     }
                  case 2:
                  case 4:
                     try {
                        this.cipher.init(false, (CipherParameters)key1);
                        break;
                     } catch (Exception var12) {
                        var30 = var12;
                        var35 = false;
                        break label139;
                     }
                  default:
                     InvalidParameterException var32;
                     try {
                        var32 = new InvalidParameterException;
                     } catch (Exception var10) {
                        var30 = var10;
                        var35 = false;
                        break label139;
                     }

                     StringBuffer var34;
                     InvalidParameterException var37;
                     try {
                        var37 = var32;
                        var34 = new StringBuffer;
                     } catch (Exception var9) {
                        var30 = var9;
                        var35 = false;
                        break label139;
                     }

                     StringBuffer var36 = var34;

                     try {
                        var36.<init>("unknown opmode ");
                        var37.<init>(var34.append(opmode).append(" passed").toString());
                        throw var32;
                     } catch (Exception var8) {
                        var30 = var8;
                        var35 = false;
                        break label139;
                     }
               }

               try {
                  return;
               } catch (Exception var7) {
                  var30 = var7;
                  var35 = false;
               }
            }

            Exception var13 = var30;
            throw new InvalidKeyException(var13.getMessage());
         }
      } else {
         throw new InvalidKeyException("Key for algorithm " + key.getAlgorithm() + " not suitable for symmetric enryption.");
      }
   }

   protected void engineInit(int opmode, Key key, AlgorithmParameters params, SecureRandom random) {
      AlgorithmParameterSpec var5 = null;
      if (params != null) {
         int var6 = 0;

         Class[] var7;
         while(var6 != (var7 = this.availableSpecs).length) {
            AlgorithmParameterSpec var10000;
            try {
               var10000 = params.getParameterSpec(var7[var6]);
            } catch (Exception var8) {
               ++var6;
               continue;
            }

            var5 = var10000;
            break;
         }

         if (var5 == null) {
            throw new InvalidAlgorithmParameterException("can't handle parameter " + params.toString());
         }
      }

      this.engineInit(opmode, key, var5, random);
      super.engineParams = params;
   }

   protected void engineInit(int opmode, Key key, SecureRandom random) {
      try {
         this.engineInit(opmode, key, (AlgorithmParameterSpec)null, random);
      } catch (InvalidAlgorithmParameterException var4) {
         throw new InvalidKeyException(var4.getMessage());
      }
   }

   protected byte[] engineUpdate(byte[] input, int inputOffset, int inputLen) {
      int var4;
      if ((var4 = this.cipher.getUpdateOutputSize(inputLen)) > 0) {
         JCEBlockCipher var10000 = this;
         byte[] var5 = new byte[var4];
         int input1;
         if ((input1 = var10000.cipher.processBytes(input, inputOffset, inputLen, var5, 0)) == 0) {
            return null;
         } else if (input1 != var4) {
            byte[] inputOffset1;
            byte[] var8 = inputOffset1 = new byte[input1];
            System.arraycopy(var5, 0, inputOffset1, 0, input1);
            return var8;
         } else {
            return var5;
         }
      } else {
         this.cipher.processBytes(input, inputOffset, inputLen, (byte[])null, 0);
         return null;
      }
   }

   protected int engineUpdate(byte[] input, int inputOffset, int inputLen, byte[] output, int outputOffset) {
      try {
         return this.cipher.processBytes(input, inputOffset, inputLen, output, outputOffset);
      } catch (DataLengthException var6) {
         throw new ShortBufferException(var6.getMessage());
      }
   }

   protected byte[] engineDoFinal(byte[] input, int inputOffset, int inputLen) {
      int var4 = 0;
      int var5;
      byte[] var6 = new byte[var5 = this.engineGetOutputSize(inputLen)];
      if (inputLen != 0) {
         var4 = this.cipher.processBytes(input, inputOffset, inputLen, var6, 0);
      }

      int var10000;
      int var10001;
      try {
         var10000 = var4;
         var10001 = this.cipher.doFinal(var6, var4);
      } catch (DataLengthException var7) {
         throw new IllegalBlockSizeException(var7.getMessage());
      } catch (InvalidCipherTextException var8) {
         throw new BadPaddingException(var8.getMessage());
      }

      int var9;
      if ((var9 = var10000 + var10001) == var5) {
         return var6;
      } else {
         byte[] var10 = input = new byte[var9];
         System.arraycopy(var6, 0, input, 0, var9);
         return var10;
      }
   }

   protected int engineDoFinal(byte[] input, int inputOffset, int inputLen, byte[] output, int outputOffset) {
      int var6 = 0;
      if (inputLen != 0) {
         var6 = this.cipher.processBytes(input, inputOffset, inputLen, output, outputOffset);
      }

      DataLengthException var13;
      label29: {
         InvalidCipherTextException var10000;
         label35: {
            int var14;
            GenericBlockCipher var15;
            boolean var10001;
            try {
               var14 = var6;
               var15 = this.cipher;
            } catch (DataLengthException var9) {
               var13 = var9;
               var10001 = false;
               break label29;
            } catch (InvalidCipherTextException var10) {
               var10000 = var10;
               var10001 = false;
               break label35;
            }

            byte[] var10002 = output;
            int var10003 = outputOffset + var6;

            try {
               int var16 = var15.doFinal(var10002, var10003);
               return var14 + var16;
            } catch (DataLengthException var7) {
               var13 = var7;
               var10001 = false;
               break label29;
            } catch (InvalidCipherTextException var8) {
               var10000 = var8;
               var10001 = false;
            }
         }

         InvalidCipherTextException var11 = var10000;
         throw new BadPaddingException(var11.getMessage());
      }

      DataLengthException var12 = var13;
      throw new IllegalBlockSizeException(var12.getMessage());
   }

   private static class AEADGenericBlockCipher implements GenericBlockCipher {
      private AEADBlockCipher cipher;

      AEADGenericBlockCipher(AEADBlockCipher cipher) {
         this.cipher = cipher;
      }

      public void init(boolean forEncryption, CipherParameters params) {
         this.cipher.init(forEncryption, params);
      }

      public String getAlgorithmName() {
         return this.cipher.getUnderlyingCipher().getAlgorithmName();
      }

      public boolean wrapOnNoPadding() {
         return false;
      }

      public BlockCipher getUnderlyingCipher() {
         return this.cipher.getUnderlyingCipher();
      }

      public int getOutputSize(int len) {
         return this.cipher.getOutputSize(len);
      }

      public int getUpdateOutputSize(int len) {
         return this.cipher.getUpdateOutputSize(len);
      }

      public int processByte(byte in, byte[] out, int outOff) {
         return this.cipher.processByte(in, out, outOff);
      }

      public int processBytes(byte[] in, int inOff, int len, byte[] out, int outOff) {
         return this.cipher.processBytes(in, inOff, len, out, outOff);
      }

      public int doFinal(byte[] out, int outOff) {
         return this.cipher.doFinal(out, outOff);
      }
   }

   public static class AES extends JCEBlockCipher {
      public AES() {
         AES var10000 = this;
         AESFastEngine var1;
         var1 = new AESFastEngine.<init>();
         var10000.<init>(var1);
      }
   }

   public static class AESCBC extends JCEBlockCipher {
      public AESCBC() {
         AESCBC var10000 = this;
         CBCBlockCipher var2;
         CBCBlockCipher var10001 = var2 = new CBCBlockCipher;
         AESFastEngine var1;
         var1 = new AESFastEngine.<init>();
         var10001.<init>(var1);
         var10000.<init>(var2, 128);
      }
   }

   public static class AESCFB extends JCEBlockCipher {
      public AESCFB() {
         AESCFB var10000 = this;
         CFBBlockCipher var2;
         CFBBlockCipher var10001 = var2 = new CFBBlockCipher;
         AESFastEngine var1;
         var1 = new AESFastEngine.<init>();
         var10001.<init>(var1, 128);
         var10000.<init>(var2, 128);
      }
   }

   public static class AESOFB extends JCEBlockCipher {
      public AESOFB() {
         AESOFB var10000 = this;
         OFBBlockCipher var2;
         OFBBlockCipher var10001 = var2 = new OFBBlockCipher;
         AESFastEngine var1;
         var1 = new AESFastEngine.<init>();
         var10001.<init>(var1, 128);
         var10000.<init>(var2, 128);
      }
   }

   public static class Blowfish extends JCEBlockCipher {
      public Blowfish() {
         Blowfish var10000 = this;
         BlowfishEngine var1;
         var1 = new BlowfishEngine.<init>();
         var10000.<init>(var1);
      }
   }

   private static class BufferedGenericBlockCipher implements GenericBlockCipher {
      private BufferedBlockCipher cipher;

      BufferedGenericBlockCipher(BufferedBlockCipher cipher) {
         this.cipher = cipher;
      }

      BufferedGenericBlockCipher(BlockCipher cipher) {
         BufferedGenericBlockCipher var10000 = this;
         super();
         PaddedBufferedBlockCipher var2;
         var2 = new PaddedBufferedBlockCipher.<init>(cipher);
         var10000.cipher = var2;
      }

      BufferedGenericBlockCipher(BlockCipher cipher, BlockCipherPadding padding) {
         BufferedGenericBlockCipher var10000 = this;
         super();
         PaddedBufferedBlockCipher var3;
         var3 = new PaddedBufferedBlockCipher.<init>(cipher, padding);
         var10000.cipher = var3;
      }

      public void init(boolean forEncryption, CipherParameters params) {
         this.cipher.init(forEncryption, params);
      }

      public boolean wrapOnNoPadding() {
         return this.cipher instanceof CTSBlockCipher ^ true;
      }

      public String getAlgorithmName() {
         return this.cipher.getUnderlyingCipher().getAlgorithmName();
      }

      public BlockCipher getUnderlyingCipher() {
         return this.cipher.getUnderlyingCipher();
      }

      public int getOutputSize(int len) {
         return this.cipher.getOutputSize(len);
      }

      public int getUpdateOutputSize(int len) {
         return this.cipher.getUpdateOutputSize(len);
      }

      public int processByte(byte in, byte[] out, int outOff) {
         return this.cipher.processByte(in, out, outOff);
      }

      public int processBytes(byte[] in, int inOff, int len, byte[] out, int outOff) {
         return this.cipher.processBytes(in, inOff, len, out, outOff);
      }

      public int doFinal(byte[] out, int outOff) {
         return this.cipher.doFinal(out, outOff);
      }
   }

   public static class CAST5 extends JCEBlockCipher {
      public CAST5() {
         CAST5 var10000 = this;
         CAST5Engine var1;
         var1 = new CAST5Engine.<init>();
         var10000.<init>(var1);
      }
   }

   public static class CAST5CBC extends JCEBlockCipher {
      public CAST5CBC() {
         CAST5CBC var10000 = this;
         CBCBlockCipher var2;
         CBCBlockCipher var10001 = var2 = new CBCBlockCipher;
         CAST5Engine var1;
         var1 = new CAST5Engine.<init>();
         var10001.<init>(var1);
         var10000.<init>(var2, 64);
      }
   }

   public static class CAST6 extends JCEBlockCipher {
      public CAST6() {
         CAST6 var10000 = this;
         CAST6Engine var1;
         var1 = new CAST6Engine.<init>();
         var10000.<init>(var1);
      }
   }

   public static class DES extends JCEBlockCipher {
      public DES() {
         DES var10000 = this;
         DESEngine var1;
         var1 = new DESEngine.<init>();
         var10000.<init>(var1);
      }
   }

   public static class DESCBC extends JCEBlockCipher {
      public DESCBC() {
         DESCBC var10000 = this;
         CBCBlockCipher var2;
         CBCBlockCipher var10001 = var2 = new CBCBlockCipher;
         DESEngine var1;
         var1 = new DESEngine.<init>();
         var10001.<init>(var1);
         var10000.<init>(var2, 64);
      }
   }

   public static class DESede extends JCEBlockCipher {
      public DESede() {
         DESede var10000 = this;
         DESedeEngine var1;
         var1 = new DESedeEngine.<init>();
         var10000.<init>(var1);
      }
   }

   public static class DESedeCBC extends JCEBlockCipher {
      public DESedeCBC() {
         DESedeCBC var10000 = this;
         CBCBlockCipher var2;
         CBCBlockCipher var10001 = var2 = new CBCBlockCipher;
         DESedeEngine var1;
         var1 = new DESedeEngine.<init>();
         var10001.<init>(var1);
         var10000.<init>(var2, 64);
      }
   }

   public static class GOST28147 extends JCEBlockCipher {
      public GOST28147() {
         GOST28147 var10000 = this;
         GOST28147Engine var1;
         var1 = new GOST28147Engine.<init>();
         var10000.<init>(var1);
      }
   }

   public static class GOST28147cbc extends JCEBlockCipher {
      public GOST28147cbc() {
         GOST28147cbc var10000 = this;
         CBCBlockCipher var2;
         CBCBlockCipher var10001 = var2 = new CBCBlockCipher;
         GOST28147Engine var1;
         var1 = new GOST28147Engine.<init>();
         var10001.<init>(var1);
         var10000.<init>(var2, 64);
      }
   }

   private interface GenericBlockCipher {
      void init(boolean var1, CipherParameters var2);

      boolean wrapOnNoPadding();

      String getAlgorithmName();

      BlockCipher getUnderlyingCipher();

      int getOutputSize(int var1);

      int getUpdateOutputSize(int var1);

      int processByte(byte var1, byte[] var2, int var3);

      int processBytes(byte[] var1, int var2, int var3, byte[] var4, int var5);

      int doFinal(byte[] var1, int var2);
   }

   public static class IDEA extends JCEBlockCipher {
      public IDEA() {
         IDEA var10000 = this;
         IDEAEngine var1;
         var1 = new IDEAEngine.<init>();
         var10000.<init>(var1);
      }
   }

   public static class IDEACBC extends JCEBlockCipher {
      public IDEACBC() {
         IDEACBC var10000 = this;
         CBCBlockCipher var2;
         CBCBlockCipher var10001 = var2 = new CBCBlockCipher;
         IDEAEngine var1;
         var1 = new IDEAEngine.<init>();
         var10001.<init>(var1);
         var10000.<init>(var2, 64);
      }
   }

   public static class PBEWithAESCBC extends JCEBlockCipher {
      public PBEWithAESCBC() {
         PBEWithAESCBC var10000 = this;
         CBCBlockCipher var2;
         CBCBlockCipher var10001 = var2 = new CBCBlockCipher;
         AESFastEngine var1;
         var1 = new AESFastEngine.<init>();
         var10001.<init>(var1);
         var10000.<init>(var2);
      }
   }

   public static class PBEWithMD5AndDES extends JCEBlockCipher {
      public PBEWithMD5AndDES() {
         PBEWithMD5AndDES var10000 = this;
         CBCBlockCipher var2;
         CBCBlockCipher var10001 = var2 = new CBCBlockCipher;
         DESEngine var1;
         var1 = new DESEngine.<init>();
         var10001.<init>(var1);
         var10000.<init>(var2);
      }
   }

   public static class PBEWithMD5AndRC2 extends JCEBlockCipher {
      public PBEWithMD5AndRC2() {
         PBEWithMD5AndRC2 var10000 = this;
         CBCBlockCipher var2;
         CBCBlockCipher var10001 = var2 = new CBCBlockCipher;
         RC2Engine var1;
         var1 = new RC2Engine.<init>();
         var10001.<init>(var1);
         var10000.<init>(var2);
      }
   }

   public static class PBEWithSHA1AndDES extends JCEBlockCipher {
      public PBEWithSHA1AndDES() {
         PBEWithSHA1AndDES var10000 = this;
         CBCBlockCipher var2;
         CBCBlockCipher var10001 = var2 = new CBCBlockCipher;
         DESEngine var1;
         var1 = new DESEngine.<init>();
         var10001.<init>(var1);
         var10000.<init>(var2);
      }
   }

   public static class PBEWithSHA1AndRC2 extends JCEBlockCipher {
      public PBEWithSHA1AndRC2() {
         PBEWithSHA1AndRC2 var10000 = this;
         CBCBlockCipher var2;
         CBCBlockCipher var10001 = var2 = new CBCBlockCipher;
         RC2Engine var1;
         var1 = new RC2Engine.<init>();
         var10001.<init>(var1);
         var10000.<init>(var2);
      }
   }

   public static class PBEWithSHAAnd128BitRC2 extends JCEBlockCipher {
      public PBEWithSHAAnd128BitRC2() {
         PBEWithSHAAnd128BitRC2 var10000 = this;
         CBCBlockCipher var2;
         CBCBlockCipher var10001 = var2 = new CBCBlockCipher;
         RC2Engine var1;
         var1 = new RC2Engine.<init>();
         var10001.<init>(var1);
         var10000.<init>(var2);
      }
   }

   public static class PBEWithSHAAnd40BitRC2 extends JCEBlockCipher {
      public PBEWithSHAAnd40BitRC2() {
         PBEWithSHAAnd40BitRC2 var10000 = this;
         CBCBlockCipher var2;
         CBCBlockCipher var10001 = var2 = new CBCBlockCipher;
         RC2Engine var1;
         var1 = new RC2Engine.<init>();
         var10001.<init>(var1);
         var10000.<init>(var2);
      }
   }

   public static class PBEWithSHAAndDES2Key extends JCEBlockCipher {
      public PBEWithSHAAndDES2Key() {
         PBEWithSHAAndDES2Key var10000 = this;
         CBCBlockCipher var2;
         CBCBlockCipher var10001 = var2 = new CBCBlockCipher;
         DESedeEngine var1;
         var1 = new DESedeEngine.<init>();
         var10001.<init>(var1);
         var10000.<init>(var2);
      }
   }

   public static class PBEWithSHAAndDES3Key extends JCEBlockCipher {
      public PBEWithSHAAndDES3Key() {
         PBEWithSHAAndDES3Key var10000 = this;
         CBCBlockCipher var2;
         CBCBlockCipher var10001 = var2 = new CBCBlockCipher;
         DESedeEngine var1;
         var1 = new DESedeEngine.<init>();
         var10001.<init>(var1);
         var10000.<init>(var2);
      }
   }

   public static class PBEWithSHAAndIDEA extends JCEBlockCipher {
      public PBEWithSHAAndIDEA() {
         PBEWithSHAAndIDEA var10000 = this;
         CBCBlockCipher var2;
         CBCBlockCipher var10001 = var2 = new CBCBlockCipher;
         IDEAEngine var1;
         var1 = new IDEAEngine.<init>();
         var10001.<init>(var1);
         var10000.<init>(var2);
      }
   }

   public static class PBEWithSHAAndTwofish extends JCEBlockCipher {
      public PBEWithSHAAndTwofish() {
         PBEWithSHAAndTwofish var10000 = this;
         CBCBlockCipher var2;
         CBCBlockCipher var10001 = var2 = new CBCBlockCipher;
         TwofishEngine var1;
         var1 = new TwofishEngine.<init>();
         var10001.<init>(var1);
         var10000.<init>(var2);
      }
   }

   public static class RC2 extends JCEBlockCipher {
      public RC2() {
         RC2 var10000 = this;
         RC2Engine var1;
         var1 = new RC2Engine.<init>();
         var10000.<init>(var1);
      }
   }

   public static class RC2CBC extends JCEBlockCipher {
      public RC2CBC() {
         RC2CBC var10000 = this;
         CBCBlockCipher var2;
         CBCBlockCipher var10001 = var2 = new CBCBlockCipher;
         RC2Engine var1;
         var1 = new RC2Engine.<init>();
         var10001.<init>(var1);
         var10000.<init>(var2, 64);
      }
   }

   public static class RC5 extends JCEBlockCipher {
      public RC5() {
         RC5 var10000 = this;
         RC532Engine var1;
         var1 = new RC532Engine.<init>();
         var10000.<init>(var1);
      }
   }

   public static class RC564 extends JCEBlockCipher {
      public RC564() {
         RC564 var10000 = this;
         RC564Engine var1;
         var1 = new RC564Engine.<init>();
         var10000.<init>(var1);
      }
   }

   public static class RC6 extends JCEBlockCipher {
      public RC6() {
         RC6 var10000 = this;
         RC6Engine var1;
         var1 = new RC6Engine.<init>();
         var10000.<init>(var1);
      }
   }

   public static class Rijndael extends JCEBlockCipher {
      public Rijndael() {
         Rijndael var10000 = this;
         RijndaelEngine var1;
         var1 = new RijndaelEngine.<init>();
         var10000.<init>(var1);
      }
   }

   public static class SEED extends JCEBlockCipher {
      public SEED() {
         SEED var10000 = this;
         SEEDEngine var1;
         var1 = new SEEDEngine.<init>();
         var10000.<init>(var1);
      }
   }

   public static class Serpent extends JCEBlockCipher {
      public Serpent() {
         Serpent var10000 = this;
         SerpentEngine var1;
         var1 = new SerpentEngine.<init>();
         var10000.<init>(var1);
      }
   }

   public static class Skipjack extends JCEBlockCipher {
      public Skipjack() {
         Skipjack var10000 = this;
         SkipjackEngine var1;
         var1 = new SkipjackEngine.<init>();
         var10000.<init>(var1);
      }
   }

   public static class TEA extends JCEBlockCipher {
      public TEA() {
         TEA var10000 = this;
         TEAEngine var1;
         var1 = new TEAEngine.<init>();
         var10000.<init>(var1);
      }
   }

   public static class Twofish extends JCEBlockCipher {
      public Twofish() {
         Twofish var10000 = this;
         TwofishEngine var1;
         var1 = new TwofishEngine.<init>();
         var10000.<init>(var1);
      }
   }

   public static class XTEA extends JCEBlockCipher {
      public XTEA() {
         XTEA var10000 = this;
         XTEAEngine var1;
         var1 = new XTEAEngine.<init>();
         var10000.<init>(var1);
      }
   }
}
